==> supplier-center-api-1.1.9-sources.jar: cn/com/duiba/supplier/center/api/dto/OrderOperationImportRecordDto.java <==
package cn.com.duiba.supplier.center.api.dto;

import java.io.Serializable;
import java.util.Date;

/**
* 订单操作导入记录
*/
public class OrderOperationImportRecordDto implements Serializable {

    private static final long serialVersionUID = 5217232281719147717L;
    /**
    * 主键id
    */
    private Long id;

    /**
    * 操作人
    */
    private String operator;

    /**
    * 文件名
    */
    private String fileName;

    /**
    * 处理方式
    */
    private String type;

    /**
    * 状态
    */
    private String status;

    /**
    * 导入总数量
    */
    private Integer totalNum;

    /**
    * 导入成功数量
    */
    private Integer successNum;

    /**
    * 导入失败数量
    */
    private Integer failNum;

    /**
    * 失败文件下载地址
    */
    private String excelUrl;

    /**
     * 业务id，具体业务会用到查询
     */
    private String bizId;

    /**
    * 创建时间
    */
    private Date gmtCreate;

    /**
    * 修改时间
    */
    private Date gmtModified;


    public void setId(Long id) {
        this.id = id;
    }

    public Long getId() {
        return id;
    }

    public void setOperator(String operator) {
        this.operator = operator;
    }

    public String getOperator() {
        return operator;
    }

    public void setFileName(String fileName) {
        this.fileName = fileName;
    }

    public String getFileName() {
        return fileName;
    }

    public void setType(String type) {
        this.type = type;
    }

    public String getType() {
        return type;
    }

    public void setStatus(String status) {
        this.status = status;
    }

    public String getStatus() {
        return status;
    }

    public void setTotalNum(Integer totalNum) {
        this.totalNum = totalNum;
    }

    public Integer getTotalNum() {
        return totalNum;
    }

    public void setSuccessNum(Integer successNum) {
        this.successNum = successNum;
    }

    public Integer getSuccessNum() {
        return successNum;
    }

    public void setFailNum(Integer failNum) {
        this.failNum = failNum;
    }

    public Integer getFailNum() {
        return failNum;
    }

    public void setExcelUrl(String excelUrl) {
        this.excelUrl = excelUrl;
    }

    public String getExcelUrl() {
        return excelUrl;
    }

    public String getBizId() {
        return bizId;
    }

    public void setBizId(String bizId) {
        this.bizId = bizId;
    }

    public void setGmtCreate(Date gmtCreate) {
        this.gmtCreate = gmtCreate;
    }

    public Date getGmtCreate() {
        return gmtCreate;
    }

    public void setGmtModified(Date gmtModified) {
        this.gmtModified = gmtModified;
    }

    public Date getGmtModified() {
        return gmtModified;
    }

}

==> supplier-center-api-2.1.53-sources.jar: cn/com/duiba/supplier/center/api/dto/OrderOperationImportRecordDto.java <==
package cn.com.duiba.supplier.center.api.dto;

import java.io.Serializable;
import java.util.Date;

/**
* 订单操作导入记录
*/
public class OrderOperationImportRecordDto implements Serializable {

    private static final long serialVersionUID = 5217232281719147717L;
    /**
    * 主键id
    */
    private Long id;

    /**
    * 操作人
    */
    private String operator;

    /**
    * 文件名
    */
    private String fileName;

    /**
    * 处理方式
    */
    private String type;

    /**
    * 状态
    */
    private String status;

    /**
    * 导入总数量
    */
    private Integer totalNum;

    /**
    * 导入成功数量
    */
    private Integer successNum;

    /**
    * 导入失败数量
    */
    private Integer failNum;

    /**
    * 失败文件下载地址
    */
    private String excelUrl;

    /**
     * 原始文件下载地址
     */
    private String originExcelUrl;

    /**
     * 业务id，具体业务会用到查询
     */
    private String bizId;

    /**
    * 创建时间
    */
    private Date gmtCreate;

    /**
    * 修改时间
    */
    private Date gmtModified;


    public void setId(Long id) {
        this.id = id;
    }

    public Long getId() {
        return id;
    }

    public void setOperator(String operator) {
        this.operator = operator;
    }

    public String getOperator() {
        return operator;
    }

    public void setFileName(String fileName) {
        this.fileName = fileName;
    }

    public String getFileName() {
        return fileName;
    }

    public void setType(String type) {
        this.type = type;
    }

    public String getType() {
        return type;
    }

    public void setStatus(String status) {
        this.status = status;
    }

    public String getStatus() {
        return status;
    }

    public void setTotalNum(Integer totalNum) {
        this.totalNum = totalNum;
    }

    public Integer getTotalNum() {
        return totalNum;
    }

    public void setSuccessNum(Integer successNum) {
        this.successNum = successNum;
    }

    public Integer getSuccessNum() {
        return successNum;
    }

    public void setFailNum(Integer failNum) {
        this.failNum = failNum;
    }

    public Integer getFailNum() {
        return failNum;
    }

    public void setExcelUrl(String excelUrl) {
        this.excelUrl = excelUrl;
    }

    public String getExcelUrl() {
        return excelUrl;
    }

    public String getOriginExcelUrl() {
        return originExcelUrl;
    }

    public void setOriginExcelUrl(String originExcelUrl) {
        this.originExcelUrl = originExcelUrl;
    }

    public String getBizId() {
        return bizId;
    }

    public void setBizId(String bizId) {
        this.bizId = bizId;
    }

    public void setGmtCreate(Date gmtCreate) {
        this.gmtCreate = gmtCreate;
    }

    public Date getGmtCreate() {
        return gmtCreate;
    }

    public void setGmtModified(Date gmtModified) {
        this.gmtModified = gmtModified;
    }

    public Date getGmtModified() {
        return gmtModified;
    }

}
